@@ -1,7 +1,7 @@
 package Bencher::Scenario::Exporters::Startup;
 
-our $DATE = '2019-08-15'; # DATE
-our $VERSION = '0.090'; # VERSION
+our $DATE = '2019-08-16'; # DATE
+our $VERSION = '0.091'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ Bencher::Scenario::Exporters::Startup - Benchmark the startup overhead of some e
 
 =head1 VERSION
 
-This document describes version 0.090 of Bencher::Scenario::Exporters::Startup (from Perl distribution Bencher-Scenarios-Exporters), released on 2019-08-15.
+This document describes version 0.091 of Bencher::Scenario::Exporters::Startup (from Perl distribution Bencher-Scenarios-Exporters), released on 2019-08-16.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ L<Exporter::Tiny> 1.000000
 
 L<PERLANCAR::Exporter::Lite> 0.02
 
-L<Perinci::Exporter> 0.080
+L<Perinci::Exporter> 0.081
 
 L<Sub::Exporter> 0.987
 
@@ -164,16 +164,16 @@ Benchmark with default options (C<< bencher -m Exporters::Startup >>):
  +---------------------------+-----------+------------------------+------------+---------+---------+
  | participant               | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------------+-----------+------------------------+------------+---------+---------+
- | Sub::Exporter             |      18.1 |     12                 |        1   | 1.4e-05 |      20 |
- | Exporter::Tiny            |       9.5 |      3.4               |        1.9 | 1.9e-05 |      20 |
- | Xporter                   |       9   |      2.9               |        2   | 2.6e-05 |      20 |
- | Exporter::Lite            |       8.4 |      2.3               |        2.2 | 2.1e-05 |      20 |
- | Perinci::Exporter         |       7.6 |      1.5               |        2.4 | 2.2e-05 |      20 |
- | Exporter::Rinci           |       6.9 |      0.800000000000001 |        2.6 | 9.2e-06 |      20 |
- | Exporter                  |       6.7 |      0.600000000000001 |        2.7 | 1.3e-05 |      20 |
- | Exporter::Tidy            |       6.6 |      0.5               |        2.7 | 1.1e-05 |      20 |
- | PERLANCAR::Exporter::Lite |       6.5 |      0.4               |        2.8 | 1.7e-05 |      20 |
- | perl -e1 (baseline)       |       6.1 |      0                 |        3   | 1.4e-05 |      21 |
+ | Sub::Exporter             |      18   |     12.1               |        1   | 3.5e-05 |      20 |
+ | Exporter::Tiny            |       9.2 |      3.3               |        2   | 1.5e-05 |      21 |
+ | Xporter                   |       8.7 |      2.8               |        2   |   2e-05 |      20 |
+ | Exporter::Lite            |       8.2 |      2.3               |        2.2 | 3.9e-05 |      20 |
+ | Perinci::Exporter         |       7.2 |      1.3               |        2.5 | 2.1e-05 |      20 |
+ | Exporter::Rinci           |       6.6 |      0.699999999999999 |        2.7 | 1.8e-05 |      20 |
+ | Exporter                  |       6.3 |      0.399999999999999 |        2.8 | 2.5e-05 |      20 |
+ | Exporter::Tidy            |       6.2 |      0.3               |        2.9 | 2.4e-05 |      23 |
+ | PERLANCAR::Exporter::Lite |       6.1 |      0.199999999999999 |        2.9 | 1.1e-05 |      20 |
+ | perl -e1 (baseline)       |       5.9 |      0                 |        3   | 3.7e-05 |      20 |
  +---------------------------+-----------+------------------------+------------+---------+---------+
 
 
